==> remmina_1.3.10+dfsg.orig.tar.xz: Remmina-v1.3.10/THANKS.md <==
# The Remmina donors

We don't disclose the exact amount of money each supporter has donated to protect their privacy as much as we can, except if otherwise requested by the donor.

As we don't have nothing to hide and as Remmina is a FLOSS project, we disclose the list of the donors, keeping at the top those that have donated more. This is not to reduce the importance of smaller donations, as we all give what we can in accordance with their own resources.

You can inquire us at any moment to know how donations are used and any details we shall share with you.

If you want to be removed, or we forgot to list your name, or you want we add more details about you, let us know.

## The Remmina Patron.

This special place is reserved to who have donated the highest amount of money since we collect donations.

- Daniel Bolter
- Rafael Wolf owner of [EITS, LLC, dba Express IT Solutions](https://eitsonline.com) Kalamazoo, MI 49048 USA. ( **Donated $100** )
- [Khalifa Alshamsi ](https://twitter.com/kha1ifa__)
- [Tim Richardson - GrowthPath founder](https://www.growthpath.com.au/people/growthpath-team-2)

## Year 2019 donors

- Daniel Bolter
- Khalifa Alshamsi (https://twitter.com/kha1ifa__)

- Abdulkarim Khormi
- Andres Zanzani
- Andrew Hart
- Benoit Mercier
- Clayton Casciato
- Dennis Lampe
- Josef Abdel Wahed
- Marcin Wolcendorf
- Marwan Yassin
- Matthias Baumann
- Matthias Tapis
- Michael Brazeau
- Márcio Oliveira Luiz
- Roman Cravtov
- Ruston Rountree
- Sergio Omiccioli
- Thomas Stofer Computerservice
- Welles Freire Ximenes
- Wolfgang Scherer

## Year 2018 donors

- Anton Karmanov
- Antonio Quinonez-Mun
- Clemens Anhuth
- CSI Dudek Marcin
- coder-zero @Future Systems bvba
- Debapriyo Sarkar
- Harjit Takshak
- Marco Polano
- Michael Hipp
- Peter Link
- Praveen Bhamidipati
- Radek Loutocký
- Richard Flathmann
- Sergey Lebfr
- Tommy Sweeney

## Year 2017 donors

- Anonymous (16)
- Brad Kulkin
- Daniel Platteau
- Dmitry Yudin
- Fuad kamal
- František Řezáč
- Jakub Kubień
- Leigh Mutimer
- Luca Menini
- Mauro Frischherz
- Paul Walker
- Tomasz Kubacki

## Year 2016 donors

These donors have contributed with an important amount of money during the year 2016

- Daniel Bolter
- Bruce Cran
- Jamison Guyton

These donors are listed in first name alphabetical order.

- Allen Smith
- Антонов Иван
- Artur Mroczko
- Bruce Cran
- Cesar Reza
- Christian Uceda
- Dietmar Wolf
- Gustavo Uceda
- Ivan Antonov
- Ivan Dobrianov
- Jamison Guyton
- Lars Povlsen
- Lynne Lawrence
- Mikhail Blinkov
- Michael Gruben
- Michael Schneider
- Nic Galler
- Patrick Saccani-Williams
- Paul Johnson
- Paul Zoulin
- Richard Lees
- Richard Pendlebury
- Stepan Naumov
- Tim Richardson
- Troy Lea
- Viktor Sik

# The Remmina community

Without the  **Remmina community**, this project wouldn't exists outside its owner workstations.

# The Remmina core team

**Antenore Gatta** ([antenore](https://github.com/antenore)) and **Giovanni Panozzo** ([giox069](https://github.com/giox069)) to have resurrected Remmina, without them,
it would be a dead project!

Long life to Remmina and their maintainers!

**Dario Cavedon** ([DarioCavedon](https://plus.google.com/+DarioCavedon)), our "everything" counselor, writer, legal adviser and social media expert.

# Most active collaborators

**Dennis Ollier** ([larchunix](https://github.com/larchunix)) for the SPICE protocol plugin.

**Luca Falavigna** ([dktrkranz](https://github.com/dktrkranz)) for his great support with the Ubuntu PPA and Remmina patches.

**Matteo F. Vescovi** ([mfvescovi](https://github.com/mfvescovi)) that has done a huge and impressive job to bring the Remmina upstream version to Debian and Ubuntu.

**Matteo Nastasi** ([nastasi](https://github.com/nastasi)) that during the years 2016 and 2017 started to implement the new receipts for Ubuntu and Debian.

**Johannes Weberhofer** ([weberhofer](https://github.com/weberhofer)) and **Pavel Alexeev** ([Hubbitus](https://github.com/Hubbitus))

**Fabio Castelli** ([muflone](https://github.com/muflone)) to have brought some great improvements and functionalities to Remmina.

# The fathers of Remmina

**Marc-André Moreau** ([awakecoding](https://github.com/awakecoding)) and **Vic Lee** ([llyzs](https://github.com/llyzs)), we are deeply grateful that you placed your
trust in us (Antenore & Giovanni) to represent Remmina.

Least but not last, the [FreeRDP](https://github.com/FreeRDP/FreeRDP) project the most advanced and updated RDP library
to date.

# The Gnome VTE project

Particularly **Egmont Koblinger** ([@egmontkob](https://github.com/egmontkob)) and **Christian Persch** for their support.

# Disclaimer

If we have forgot anybody or the data in here is wrong don't hesitate to contact us ASAP. We will fix and/or add whatever is missing or wrong immediately.

==> remmina_1.4.1+dfsg.orig.tar.xz: Remmina-v1.4.1/THANKS.md <==
# The Remmina donors

We don't disclose the exact amount of money each supporter has donated to protect their privacy as much as we can, except if otherwise requested by the donor.

As we don't have nothing to hide and as Remmina is a FLOSS project, we disclose the list of the donors, keeping at the top those that have donated more. This is not to reduce the importance of smaller donations, as we all give what we can in accordance with their own resources.

You can inquire us at any moment to know how donations are used and any details we shall share with you.

If you want to be removed, or we forgot to list your name, or you want we add more details about you, let us know.

## The Remmina Patron.

This special place is reserved to who have donated the highest amount of money since we collect donations.

- Daniel Bolter
- Rafael Wolf owner of [EITS, LLC, dba Express IT Solutions](https://eitsonline.com) Kalamazoo, MI 49048 USA. ( **Donated $100** )
- [Khalifa Alshamsi ](https://twitter.com/kha1ifa__)
- [Tim Richardson - GrowthPath founder](https://www.growthpath.com.au/people/growthpath-team-2)

## Year 2020 donors

- Абрамов Павел
- Peter Vollebregt

## Year 2019 donors

- Daniel Bolter
- Khalifa Alshamsi (https://twitter.com/kha1ifa__)
- Christian Houle
- Ingo Humann
- Justin Scott
- Luděk Habarta

- atzk
- Abdulkarim Khormi
- Андрей Коробков
- Andres Zanzani
- Andrew Hart
- Antonio Quinonez-Mun
- Balvas Eugene
- Benoit Mercier
- Blagoy Chepelov
- Clayton Casciato
- Clemens Eberwein
- Cordula Herzog
- Denis Đukić
- Dennis Lampe
- Denoid Tucker
- EXCOMEDIA, Inc.
- Герун Данил
- Graham Sivill
- Gunter Moegel
- Hawkins IT Group Inc
- Hector SAenz
- Исаков Андрей
- Janez Košmrlj
- Jonathan Rogers
- Josef Abdel Wahed
- Jürgen Müller
- Клюенков Алексей
- Lance Edusei
- Подловилин Виталий
- Lutz Urban
- Majed Zouhairy
- Manuel Moelgg
- Мантуров Дмитрий
- Marc Schlegel
- Marcel Pötter
- Marcel Ostrovsky
- Marcin Wolcendorf
- Marjan Bugarinović
- Marko Milosavljevic
- Markus Heimberg
- Marwan Yassin
- Matteo Biaggi
- Matthias Baumann
- Matthias Tapis
- Mathieu Morlon
- Michael Brazeau
- Márcio Oliveira Luiz
- Nils Panitzsch
- Per Arnold Blaasmo
- Petar Kulić
- Philipp Köhler
- Roman Cravtov
- Robert Premuž
- Ross Philip
- Ruston Rountree
- Sergio Omiccioli
- Thomas Stofer Computerservice
- Trond Nystuen
- Werner Mittermayer
- Welles Freire Ximenes
- Wolfgang Scherer

## Year 2018 donors

- Anton Karmanov
- Antonio Quinonez-Mun
- Clemens Anhuth
- CSI Dudek Marcin
- coder-zero @Future Systems bvba
- Debapriyo Sarkar
- Harjit Takshak
- Marco Polano
- Michael Hipp
- Peter Link
- Praveen Bhamidipati
- Radek Loutocký
- Richard Flathmann
- Sergey Lebfr
- Tommy Sweeney

## Year 2017 donors

- Anonymous (16)
- Brad Kulkin
- Daniel Platteau
- Dmitry Yudin
- Fuad kamal
- František Řezáč
- Jakub Kubień
- Leigh Mutimer
- Luca Menini
- Mauro Frischherz
- Paul Walker
- Tomasz Kubacki

## Year 2016 donors

These donors have contributed with an important amount of money during the year 2016

- Daniel Bolter
- Bruce Cran
- Jamison Guyton

These donors are listed in first name alphabetical order.

- Allen Smith
- Антонов Иван
- Artur Mroczko
- Bruce Cran
- Cesar Reza
- Christian Uceda
- Dietmar Wolf
- Gustavo Uceda
- Ivan Antonov
- Ivan Dobrianov
- Jamison Guyton
- Lars Povlsen
- Lynne Lawrence
- Mikhail Blinkov
- Michael Gruben
- Michael Schneider
- Nic Galler
- Patrick Saccani-Williams
- Paul Johnson
- Paul Zoulin
- Richard Lees
- Richard Pendlebury
- Stepan Naumov
- Tim Richardson
- Troy Lea
- Viktor Sik

# The Remmina community

Without the  **Remmina community**, this project wouldn't exists outside its owner workstations.

# The Remmina core team

**Antenore Gatta** ([antenore](https://github.com/antenore)) and **Giovanni Panozzo** ([giox069](https://github.com/giox069)) to have resurrected Remmina, without them,
it would be a dead project!

Long life to Remmina and their maintainers!

**Dario Cavedon** ([DarioCavedon](https://plus.google.com/+DarioCavedon)), our "everything" counselor, writer, legal adviser and social media expert.

# Most active collaborators

**Dennis Ollier** ([larchunix](https://github.com/larchunix)) for the SPICE protocol plugin.

**Luca Falavigna** ([dktrkranz](https://github.com/dktrkranz)) for his great support with the Ubuntu PPA and Remmina patches.

**Matteo F. Vescovi** ([mfvescovi](https://github.com/mfvescovi)) that has done a huge and impressive job to bring the Remmina upstream version to Debian and Ubuntu.

**Matteo Nastasi** ([nastasi](https://github.com/nastasi)) that during the years 2016 and 2017 started to implement the new receipts for Ubuntu and Debian.

**Johannes Weberhofer** ([weberhofer](https://github.com/weberhofer)) and **Pavel Alexeev** ([Hubbitus](https://github.com/Hubbitus))

**Fabio Castelli** ([muflone](https://github.com/muflone)) to have brought some great improvements and functionalities to Remmina.

# The fathers of Remmina

**Marc-André Moreau** ([awakecoding](https://github.com/awakecoding)) and **Vic Lee** ([llyzs](https://github.com/llyzs)), we are deeply grateful that you placed your
trust in us (Antenore & Giovanni) to represent Remmina.

Least but not last, the [FreeRDP](https://github.com/FreeRDP/FreeRDP) project the most advanced and updated RDP library
to date.

# The Gnome VTE project

Particularly **Egmont Koblinger** ([@egmontkob](https://github.com/egmontkob)) and **Christian Persch** for their support.

# Disclaimer

If we have forgot anybody or the data in here is wrong don't hesitate to contact us ASAP. We will fix and/or add whatever is missing or wrong immediately.
